"""Generated types from JSON schemas — do not edit manually."""

from screencast_narrator_client.generated.storyboard_types import (
    HighlightStyle,
    Model as StoryboardModel,
    Narration,
    Options,
    ScreenAction,
    ScreenActionTiming,
    ScreenActionType,
)
from screencast_narrator_client.generated.qr_payload_types import (
    MarkerPosition,
    SyncType,
)

__all__ = [
    "HighlightStyle",
    "MarkerPosition",
    "Narration",
    "Options",
    "ScreenAction",
    "ScreenActionTiming",
    "ScreenActionType",
    "StoryboardModel",
    "SyncType",
]
